Dojo Toolkit - Declaration test

### Simple macro:

(Check to make sure that links contain employee number)

${name} update delete

### Using data-dojo-attach-event, data-dojo-attach-point

XXX
XXX

### Extending another widget

HideButton2 extends HideButton (above) and changes the template (but keeps the onclick handler).

YYY
YYY

### Using dojo/method:

thinger blah stuff ${foo}

baz thud

### Using dojo/aspect:

thinger blah stuff ${foo}

baz thud

### data-dojo-attach-event on root node

click me